@@ -12,8 +12,10 @@ __author__ = "yanyongyu"
 
 from contextlib import asynccontextmanager
 from typing import Optional, AsyncIterator
+from nonebot.log import logger
 
-from playwright.async_api import Page, Browser, async_playwright
+
+from playwright.async_api import Page, Browser, async_playwright, Error
 
 _browser: Optional[Browser] = None
 _playwright = None
@@ -22,10 +24,18 @@ async def init(**kwargs) -> Browser:
     global _browser
     global _playwright
     _playwright = await async_playwright().start()
-    _browser = await _playwright.chromium.launch(**kwargs)
+    try:
+        _browser = await launch_browser(**kwargs)
+    except Error:
+        await install_browser()
+        _browser = await launch_browser(**kwargs)
     return _browser
 
 
+async def launch_browser(**kwargs) -> Browser:
+    return await _playwright.chromium.launch(**kwargs)
+
+
 async def get_browser(**kwargs) -> Browser:
     return _browser or await init(**kwargs)
 
@@ -43,3 +53,14 @@ async def get_new_page(**kwargs) -> AsyncIterator[Page]:
 async def shutdown_browser():
     await _browser.close()
     await _playwright.stop()
+
+
+async def install_browser():
+    logger.info("正在安装 chromium")
+    import sys
+    from playwright.__main__ import main
+    sys.argv = ['', 'install', 'chromium']
+    try:
+        main()
+    except SystemExit:
+        pass
