@@ -6,7 +6,7 @@ import jinja2
 import markdown
 from jinja2.environment import Template
 from nonebot.log import logger
-
+from typing import Optional
 from .browser import get_new_page
 
 TEMPLATES_PATH = str(Path(__file__).parent / "templates")
@@ -70,6 +70,7 @@ async def md_to_pic(
             "fenced_code",
             "codehilite",
             "mdx_math",
+            "pymdownx.tilde",
         ],
         extension_configs={"mdx_math": {"enable_dollar_delimiter": True}},
     )
@@ -197,3 +198,12 @@ async def template_to_pic(
         wait=wait,
         **pages,
     )
+
+
+async def capture_element(
+    url: str, element: str, timeout: Optional[float] = 0, **kwargs
+) -> bytes:
+    async with get_new_page(**kwargs) as page:
+        await page.goto(url, timeout=timeout)
+        img_raw = await page.locator(element).screenshot()
+    return img_raw
